Place as much speckle automate code here
so that there is as little code as possible
in the the repo that the speckle automate workflow wants to
[create](https://github.com/specklesystems/speckle_automate_python_example).


copy paste into the `main.py` file in the speckle automate workflow repo
the function input def `class FunctionInputs(AutomateBase)`
and make a 'release'.

todo:
* parameterize ?
